import { t } from '@opentinyvue/vue-locale';
import { renderless, api } from '@opentinyvue/vue-renderless/mini-picker/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import PickerColumn from '@opentinyvue/vue-picker-column';
import '@opentinyvue/vue-theme-mobile/mini-picker/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var $constants = {
  CHILDREN_PICKER: "childrenPicker"
};
var __vue2_script = defineComponent({
  name: $prefix + "MiniPicker",
  components: {
    PickerColumn
  },
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    columns: {
      type: Array,
      default: function _default2() {
        return [];
      }
    },
    visible: {
      type: Boolean,
      default: false
    },
    title: {
      type: String,
      default: ""
    },
    confirmButtonText: {
      type: String,
      default: function _default3() {
        return t("ui.miniPicker.confirm");
      }
    },
    cancelButtonText: {
      type: String,
      default: function _default4() {
        return t("ui.miniPicker.cancel");
      }
    },
    defaultIndex: {
      type: Number,
      default: 0
    },
    valueKey: {
      type: String,
      default: "text"
    },
    itemHeight: {
      type: Number,
      default: 34
    },
    visibleItemCount: {
      type: Number,
      default: 5
    },
    swipeDuration: {
      type: Number,
      default: 1e3
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "tiny-mobile-mini-picker",
    on: {
      "click": _vm.visibleHandle
    }
  }, [_c("div", {
    staticClass: "tiny-mobile-mini-picker__mask"
  }), _c("div", {
    class: ["tiny-mobile-mini-picker__content", _vm.state.toggle ? "is-toggle" : ""]
  }, [_c("div", {
    staticClass: "tiny-mobile-mini-picker__toolbar"
  }, [_vm._t("toolbar", function() {
    return [_c("div", {
      staticClass: "picker_action picker_cancel",
      on: {
        "click": _vm.cancel
      }
    }, [_vm._v(" " + _vm._s(_vm.cancelButtonText) + " ")]), _c("div", {
      staticClass: "picker_action picker_title"
    }, [_vm._v(_vm._s(_vm.title))]), _c("div", {
      staticClass: "picker_action picker_confirm",
      on: {
        "click": _vm.confirm
      }
    }, [_vm._v(" " + _vm._s(_vm.confirmButtonText) + " ")])];
  })], 2), _c("div", {
    staticClass: "tiny-mobile-mini-picker__columns",
    style: {
      height: _vm.state.clumnsWrapHeight + "px"
    }
  }, _vm._l(_vm.state.formattedColumns, function(item, index) {
    return _c("picker-column", {
      key: index,
      ref: "childrenPicker" + index,
      refInFor: true,
      attrs: {
        "columns-item": item,
        "default-index": item.defaultIndex || +_vm.state.defaultIndex,
        "item-height": _vm.itemHeight,
        "swipe-duration": _vm.swipeDuration,
        "value-key": _vm.valueKey,
        "visible-item-count": _vm.visibleItemCount
      },
      on: {
        "change": function change($event) {
          return _vm.change(index);
        }
      }
    });
  }), 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var MiniPicker = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
MiniPicker.install = function(Vue) {
  Vue.component(MiniPicker.name, MiniPicker);
};
MiniPicker.version = version;

export { MiniPicker as default };
